% function to plot a graph with the width of the black line on the edges proportional 
% to the conductance on the edge, the size of the nodes proportional to the number of particles on the node
% first wriiten by Andrea Perna
% modified by Qi Ma ()


function plot_sigma_with_n(inputGraph, targetFigure)

%% define a nice colormap
myColormap=jet(256);


%% first plot the edges

xSources = inputGraph.nodes.x(inputGraph.edges.source);
xDest  = inputGraph.nodes.x(inputGraph.edges.dest);
ySources = inputGraph.nodes.y(inputGraph.edges.source);
yDest  = inputGraph.nodes.y(inputGraph.edges.dest);
weights = inputGraph.edges.sigma;
channel = weights; 

edgeHandle(1:length(xSources))=NaN;
hd=figure(targetFigure);
set(hd,'visible','off');
set(gca,'box','on');
set(gca,'XTick',[]);
set(gca,'YTick',[]);
cla

%% plot the grids
for j=1:length(xSources)
	% the edgeHandle is useful if we want just to change the edge
	% properties with something like set(edgeHandle, 'Color', ...)
	% we may want the function to return the edgeHandle
    edgeHandle(j)=line([xSources(j); xDest(j)], [ySources(j), yDest(j)],'Color', [0.86 0.86 0.86],'LineWidth', 5);
end

hold on;

%% plot the conductance
for j=1:length(xSources)
	% the edgeHandle is useful if we want just to change the edge
	% properties with something like set(edgeHandle, 'Color', ...)
	% we may want the function to return the edgeHandle
    if (weights(j)>1e-3)
        edgeHandle(j)=line([xSources(j); xDest(j)], [ySources(j), yDest(j)],'Color', [0 0 0],'LineWidth', min(weights(j),10));
    end
end


%% plot the nodes (source is pink, sink is green)
for j=1:length(inputGraph.nodes.x)
    plot(inputGraph.nodes.x(j), inputGraph.nodes.y(j), 'Color', [min(0.99,inputGraph.nodes.z(j)+0.2) 0.7 0.7], ...
	'Marker', 'o', ...
    'MarkerFaceColor',[min(0.99,inputGraph.nodes.z(j)+0.2) 0.7 0.7],...
	'LineStyle', 'none', ...
	'MarkerSize', min(max(inputGraph.nodes.n(j)/20,1),15));
end

axis manual
axis([min(xSources)-(max(xSources)-min(xSources))*0.09  max(xSources)+(max(xSources)-min(xSources))*0.09  min(ySources)-(max(ySources)-min(ySources))*0.1 max(ySources)+(max(ySources)-min(ySources))*0.1]);

hold off



		 
