%% function read_graph
% input : pajek formatted graph
% output : the graph written in a matlab structure
% notice that I prefer to have struct of the type:
% "nodes.number(:)"
% than structures of the type
% "nodes(:).number"
% The way I do is perhaps less clear, but it is easier to extract back
% arrays from the structures
% Andrea 13 Oct 2010


function outputGraph = read_graph(inputFile)

% Useful variables
header='';
numberOfVertices=0;

%% open the file
fid=fopen(inputFile,'r');
while (numberOfVertices==0)
	lineBuffer=fgetl(fid);
	[header, numberOfVertices] = strread(lineBuffer, '%s %d');
end;


%% initialize empy nodes structure (only useful for speed)
nodes.number(1:numberOfVertices)=NaN;
nodes.label(1:numberOfVertices)=NaN;
nodes.x(1:numberOfVertices)=NaN;
nodes.y(1:numberOfVertices)=NaN;
nodes.z(1:numberOfVertices)=NaN;

%add attributes to nodes
nodes.b(1:numberOfVertices)=NaN;  % fixed external current source
nodes.n(1:numberOfVertices)=NaN;  % number of particles

%% read the nodes from the file (disregard the label)
nodeCounter=0;
while 1
	lineBuffer=fgetl(fid);
	if ((~isempty(lineBuffer)) && (lineBuffer(1)~='*') && (lineBuffer(1)~=' ')),
		nodeCounter = nodeCounter+1;
		[nodes.number(nodeCounter), nodes.label(nodeCounter), nodes.x(nodeCounter), nodes.y(nodeCounter), nodes.z(nodeCounter)] = strread(lineBuffer, '%d %f %f %f %f');
        nodes.b(nodeCounter)=0;   
        nodes.n(nodeCounter)= 0;
	elseif ((~isempty(lineBuffer)) && (lineBuffer(1)=='*')),
		break;
	end;
end;
nodes.b(1)=1;  % set the initial external current
nodes.b(numberOfVertices)=-1;


%% read the edges from the file
edgeCounter=0;
while ~feof(fid),
	lineBuffer=fgetl(fid);
	if ((~isempty(lineBuffer)) && (lineBuffer(1)~=' ')),
		edgeCounter = edgeCounter +1;
		[edges.number(edgeCounter), edges.source(edgeCounter), edges.dest(edgeCounter), edges.weight(edgeCounter)] = strread(lineBuffer, '%d %d %d %f');
        edges.length(edgeCounter)=1;
        edges.sigma(edgeCounter)=1;
        edges.phi(edgeCounter)=1;
	end;
end;

outputGraph.nodes=nodes;
outputGraph.edges=edges;

fclose(fid);

